@@ -1,7 +1,7 @@
 #![cfg(ocvrs_has_module_imgproc)]
 
 use opencv::{
-	core::{Point, Point2f, Scalar, Size, Vec2f},
+	core::{Point, Point2f, Scalar, Size, Vec2f, Mat_AUTO_STEP},
 	imgproc,
 	prelude::*,
 	Result,
@@ -41,3 +41,25 @@ fn get_rotation_matrix_2d() -> Result<()> {
 	assert_eq!(-*mat.at_2d::<f64>(0, 1)?, *mat.at_2d::<f64>(1, 0)?);
 	Ok(())
 }
+
+#[test]
+fn line_iterator() -> Result<()> {
+	let mut data = [
+		 1,  2,  3,
+		 4,  5,  6,
+		 7,  8,  9,
+		10, 11, 12u8,
+	];
+	let mat = unsafe { Mat::new_rows_cols_with_data(4, 3, u8::typ(), data.as_mut_ptr() as *mut _, Mat_AUTO_STEP) }?;
+	let mut line_iter = imgproc::LineIterator::new(&mat, Point::new(0, 0), Point::new(2, 2), 8, false)?;
+	assert_eq!(3, line_iter.count());
+	assert_eq!(Point::new(0, 0), line_iter.pos()?);
+	assert_eq!(1, unsafe { *line_iter.try_deref_mut()?.as_ref().unwrap() });
+	line_iter.incr()?;
+	assert_eq!(Point::new(1, 1), line_iter.pos()?);
+	assert_eq!(5, unsafe { *line_iter.try_deref_mut()?.as_ref().unwrap() });
+	line_iter.incr()?;
+	assert_eq!(Point::new(2, 2), line_iter.pos()?);
+	assert_eq!(9, unsafe { *line_iter.try_deref_mut()?.as_ref().unwrap() });
+	Ok(())
+}
